@@ -60,7 +60,7 @@ async def start_viewer(
         params['symbol'] = symbol
     if index is not None:
         params['index'] = index
-    result = invoke_viewer_command('start', 'ready', params, timeout=300.0)
+    result = invoke_viewer_command('start', 'ready', params, timeout=10.0)
     error_msg = result.get('error')
     if isinstance(error_msg, str) and error_msg:
         raise ToolError(f'viewer reported error: {error_msg}')
@@ -101,7 +101,7 @@ async def rotate_viewer(
     if normalized not in allowed:
         raise ValueError(f'direction must be one of {sorted(allowed)}')
     params: dict[str, object | None] = {'viewer': viewer_id, 'direction': normalized}
-    result = invoke_viewer_command('rotate', 'rotate', params, timeout=60.0)
+    result = invoke_viewer_command('rotate', 'rotate', params, timeout=10.0)
     error_msg = result.get('error')
     if isinstance(error_msg, str) and error_msg:
         if is_focus_only(viewer_id):
@@ -129,7 +129,7 @@ async def show_structures(
     flags = [_normalize_visibility(entry) for entry in visibility]
     payload = json.dumps(flags)
     params: dict[str, object | None] = {'viewer': viewer_id, 'visibility': payload}
-    result = invoke_viewer_command('visibility', 'visibility', params, timeout=60.0)
+    result = invoke_viewer_command('visibility', 'visibility', params, timeout=10.0)
     error_msg = result.get('error')
     if isinstance(error_msg, str) and error_msg:
         if is_focus_only(viewer_id):
@@ -143,26 +143,22 @@ async def show_structures(
 
 
 async def check_simulation(viewer_id: str) -> dict[str, Any]:
-    """Fetch the latest validation status for an open viewer panel.
-
-    Args:
-        viewer_id: Identifier returned by :func:`start_viewer`.
-
-    Returns:
-        Mapping containing ``viewer_id``, any ``warnings``, optional ``error``/``status`` fields.
-    """
+    """Return viewer validation state as a mapping with ``status`` plus optional ``warnings`` or ``error``."""
     if not viewer_id:
         raise ValueError('viewer_id is required')
     params: dict[str, object | None] = {'viewer': viewer_id}
-    result = invoke_viewer_command('check', 'check', params, timeout=60.0)
-    response: dict[str, Any] = {'viewer_id': viewer_id}
+    result = invoke_viewer_command('check', 'check', params, timeout=10.0)
+    response: dict[str, Any] = {}
     warnings = _normalize_warnings(result.get('warnings'))
     if warnings is not None:
         response['warnings'] = warnings
     error_msg = result.get('error')
     if isinstance(error_msg, str) and error_msg:
         response['error'] = error_msg
-    status = result.get('status')
-    if isinstance(status, str) and status:
-        response['status'] = status
+    if 'error' in response:
+        response['status'] = 'error'
+    elif 'warnings' in response:
+        response['status'] = 'warning'
+    else:
+        response['status'] = 'ok'
     return response
